#! /bin/sh

######################################################################
# Tests the values of variables in the "jcs.conf" file.
######################################################################

error_count=0

if [ ! -f "jcs.conf" ]; then
    echo "*** ERROR: couldn't find file 'jcs.conf'."
    echo "           This file should be copied from default-jcs.conf and"
    echo "           modified to reflect your setup."
    exit 1
fi

. "./jcs.conf"

locate_java_vm=`type "$java_vm"`
echo "Checking for Java VM command."
if [ $? -ne 0 ]; then
    echo "*** ERROR: no command matching \$java_vm variable: '$java_vm'"
    exit 1   # fatal error
else
    exact_java_vm=`which "$java_vm" | head -n 1`
    echo " - Found match for \$java_vm variable [$locate_java_vm]."
fi

echo
echo "Checking for program JAR file."
if [ -f "$jcs_jar" ]; then
    echo " - Found installed jar file."
    program_output=`$java_vm -classpath "$jcs_jar" Test identify`
    if [ "$program_output" = "JavaCompileServer" ]; then
        echo " - JAR file seems to contain program."
    else
        echo "*** ERROR: \$jcs_jar variable points to an invalid JAR file:"
        echo "               '$jcs_jar'"
        echo "       The JAR file doesn't seem to contain the JCS program."
        echo "       in it (the test program wouldn't run correctly).  Are"
        echo "       you sure that the file contains ALL of the compiled"
        echo "       .class files?"
        exit 1   # fatal error
    fi
else
    echo "*** ERROR: \$jcs_jar variable points to non-existent file:"
    echo "               '$jcs_jar'"
    echo "           Are you sure you compiled and copied the program over as"
    echo "           specified in the INSTALL file?"
    exit 1   # fatal error
fi

echo
echo "Checking for JDK compiler."
if [ -f "$compiler_jar" ]; then
    echo " - Found the Sun compiler's JAR file [$compiler_jar]"
    loader_output=`$java_vm -classpath "$compiler_jar":"$jcs_jar" Test compiler 2> /dev/null`
    if [ $? -eq 0 ]; then
        echo " - Was able to load the JDK compiler [$loader_output]."
    else
        echo "*** ERROR: It looks like I was unable to run the compiler from the"
        echo "           JAR file provided in the \$compiler_jar variable.  An"
        echo "           attempt to load the compiler produces this:"
        $java_vm -classpath "$compiler_jar":"$jcs_jar" TestCompiler 2>&1
        error_count=`expr $error_count + 1`
    fi
else
    echo "*** ERROR: couldn't find the compiler JAR file specified by \$compiler_jar: '$compiler_jar'."
    error_count=`expr $error_count + 1`
fi

echo
echo "Testing passphrase generator."
random_text=`passphrase_generator`
if [ $? -ne 0 ]; then
    echo "*** ERROR: execution of the passphrase_generator function failed:"
    echo "      > $passphrase_generator"
    error_count=`expr $error_count + 1`
else
    num_letters=`echo $random_text | wc -c`
    num_letters=`echo $num_letters`
    if [ $num_letters -gt 20 ]; then
        echo " - The random text generation seems to have been successful."
    else
        echo "*** ERROR: generated text is extremely short (less than 6"
        echo "           characters.  Are you sure the command is working"
        echo "           properly?"
        echo "      > $passphrase_generator"
        error_count=`expr $error_count + 1`
    fi
    echo "       output='$random_text'"
fi

echo
echo "Checking for miscellaneous utilities."
locate_netcat="`type "$netcat"`"
if [ $? -ne 0 ]; then
    echo "*** ERROR: no command matching \$netcat variable: '$netcat'"
    error_count=`expr $error_count + 1`
else
    echo " - Found match for \$netcat variable [$locate_netcat]."
fi
locate_mktemp="`type "$mktemp"`"
if [ $? -ne 0 ]; then
    echo "*** ERROR: no command matching \$mktemp variable: '$mktemp'"
    error_count=`expr $error_count + 1`
else
    echo " - Found match for \$mktemp variable [$locate_mktemp]."
fi

echo
echo "FINISHED: $error_count error(s)"

