class Options {
    private final void initializeDirectories() {
        String userHome = System.getProperty("user.home");
        String configDir = userHome + "/.config/JavaCompileServer";
        this.portFile = configDir + "/port";
        this.passFile = configDir + "/pass";
        this.killFile = configDir + "/kill";
        this.logFile = configDir + "/log";
        this.signalFile = configDir + "/signal";
    }
    public Options() {
        int port = port_DEFAULT;
        initializeDirectories();
    }
    private int readInteger(String name, String value) throws OptionsException {
        try {
            return (Integer.parseInt(value));
        } catch (NumberFormatException ex) {
            throw new OptionsException("Invalid value for '" + name + "' option: '" + value + "'.  Value must be an integer.");
        }
    }
    public Options(String[] args) throws OptionsException {
        initializeDirectories();
        this.port = 0;
        for (int i = 0; i < args.length; i++) {
            String pair = args[i];
            int length = pair.length();
            if (length < 1) throw new OptionsException("Argument " + (i + 1) + " is zero-length.");
            int divider = pair.indexOf('=');
            if (divider < 0) throw new OptionsException("Argument " + (i + 1) + " doesn't have an equals sign (necessary to specify a key-value pair).");
            if (divider < 1) throw new OptionsException("Argument " + (i + 1) + " has a zero-length option name.");
            String key = pair.substring(0, divider);
            String value = pair.substring(divider + 1);
            if (key.equals("port")) {
                this.port = readInteger("port", value);
                if (this.port < 0 || this.port > 65535) throw new OptionsException("Invalid value for 'port' option: " + this.port + ".  Port number must be between 0 and 65535.");
            } else if (key.equals("port-file")) {
                this.portFile = value;
            } else if (key.equals("kill-file")) {
                this.killFile = value;
            } else if (key.equals("signal-file")) {
                this.signalFile = value;
            } else if (key.equals("pass-file")) {
                this.passFile = value;
            } else if (key.equals("log-file")) {
                this.logFile = value;
            } else {
                throw new OptionsException("argument " + (i + 1) + " contains an unrecognized option: '" + key + "'");
            }
        }
    }
    public int port;
    public String portFile;
    public String killFile;
    public String passFile;
    public String signalFile;
    public String logFile;
    public static final int port_DEFAULT = 0;
    public static final String portFile_DEFAULT = "[HOME_DIR]/.config/cakoose/JavaCompileServer/port";
    public static final String passFile_DEFAULT = "[HOME_DIR]/.config/cakoose/JavaCompileServer/pass";
    public static final String killFile_DEFAULT = "[HOME_DIR]/.config/cakoose/JavaCompileServer/kill";
    public static final String signalFile_DEFAULT = "[HOME_DIR]/.config/cakoose/JavaCompileServer/signal";
    public static final String logFile_DEFAULT = "[HOME_DIR]/.config/cakoose/JavaCompileServer/log";

    public static class OptionsException extends Exception {
        private String message;
        public OptionsException(String message) {
            this.message = message;
        }
        public String toString() {
            return (message);
        }
    }

    public static final String USAGE =
            "USAGE: command [ option1=value1 option2=value2 ... ]\n\n" +
            "OPTIONS:\n\n" +
            "    pass-file     The first line of this file will be used as\n" +
            "                  the server password.  Clients that connect\n" +
            "                  must provide this before their requests are\n" +
            "                  honored (must be ascii text).\n" +
            "                  DEFAULT='" + passFile_DEFAULT + "'\n\n" +
            "    port-file     A file to write the port number to.\n" +
            "                  DEFAULT='" + portFile_DEFAULT + "'.\n\n" +
            "    kill-file     The server will check for this file periodically.\n" +
            "                  If it exists, server will shut down.\n" +
            "                  DEFAULT='" + killFile_DEFAULT + "'.\n\n" +
            "    signal-file   The server will create this file upon succesful.\n" +
            "                  startup.\n" +
            "                  DEFAULT='" + signalFile_DEFAULT + "'.\n\n" +
            "    log-file      The log file.\n" +
            "                  DEFAULT='" + logFile_DEFAULT + "'.\n\n" +
            "    port          The port number to listen on.  Zero means any\n" +
            "                  any port.  DEFAULT=" + port_DEFAULT + ".\n\n" +
            "";
}


