import java.io.PrintStream;

class Statistics {

    public Statistics() {
        this.totalConnects = 0;
        this.authorizedConnects = 0;
        this.totalRequests = 0;
        this.statisticsRequests = 0;
        this.compileRequests = 0;
        this.compilationsPerformed = 0;
        this.errorCompilations = 0;
        this.compilationTime = 0;
    }

    private int totalConnects;
    private int authorizedConnects;
    private int totalRequests;
    private int statisticsRequests;

    private int compileRequests;
    private int compilationsPerformed;
    private int errorCompilations;
    private long compilationTime;

    public synchronized void addConnect() {
        this.totalConnects++;
    }
    public synchronized void addAuthorizedConnect() {
        this.authorizedConnects++;
    }
    public synchronized void addRequest() {
        this.totalRequests++;
    }
    public synchronized void addStatisticsRequest() {
        this.statisticsRequests++;
    }
    public synchronized void addCompileRequest() {
        this.compileRequests++;
    }
    public synchronized void addCompilationTime(long time, int returnCode) {
        this.compilationTime += time;
        this.compilationsPerformed++;
        if (returnCode != 0) {
            errorCompilations++;
        }
    }

    void print(PrintStream out) {
        int totalConnects;
        int authorizedConnects;
        int totalRequests;
        int statisticsRequests;
        int compileRequests;
        int compilationsPerformed;
        int errorCompilations;
        long compilationTime;

        synchronized (this) {
            totalConnects = this.totalConnects;
            authorizedConnects = this.authorizedConnects;
            totalRequests = this.totalRequests;
            statisticsRequests = this.statisticsRequests;
            compileRequests = this.compileRequests;
            compilationsPerformed = this.compilationsPerformed;
            errorCompilations = this.errorCompilations;
            compilationTime = this.compilationTime;
        }

        out.println("Connections [total = authorized + unauthorized]: " + totalConnects
                                                                        + " = " + authorizedConnects
                                                                        + " + " + (totalConnects - authorizedConnects));
        out.println("Requests [total = compile + info + invalid]: "   + totalRequests
                                                              + " = " + compileRequests
                                                              + " + " + statisticsRequests
                                                              + " + " + (totalRequests - compileRequests - statisticsRequests));
        out.println("Compilation Requests [total = valid + invalid]: "
                                                                      + compileRequests
                                                              + " = " + compilationsPerformed
                                                              + " + " + (compileRequests - compilationsPerformed));
        out.println("Compilations [total = error + error-free]: "
                                                                      + compilationsPerformed
                                                              + " = " + errorCompilations
                                                              + " + " + (compilationsPerformed - errorCompilations));
        int divider = compilationsPerformed;
        if (divider == 0) divider = 1;
        out.println("Compilation Time (millis) [average (total)]: " + (compilationTime / divider) + " (" + compilationTime + ")");
    }


}
